@@ -221,10 +221,11 @@ class ImportAPI(generics.CreateAPIView):
             # after bulk create we can bulk update tasks stats with
             # flag_update_stats=True but they are already updated with signal in same transaction
             # so just update tasks_number_changed
-            project.update_tasks_states(
+            project.update_tasks_states_with_counters(
                 maximum_annotations_changed=False,
                 overlap_cohort_percentage_changed=False,
-                tasks_number_changed=True
+                tasks_number_changed=True,
+                tasks_queryset=tasks
             )
             logger.info('Tasks bulk_update finished')
 
@@ -280,7 +281,7 @@ class ImportPredictionsAPI(generics.CreateAPIView):
                 model_version=item.get('model_version', 'undefined')
             ))
         predictions_obj = Prediction.objects.bulk_create(predictions, batch_size=settings.BATCH_SIZE)
-
+        project.update_tasks_counters(Task.objects.filter(id__in=tasks_ids))
         return Response({'created': len(predictions_obj)}, status=status.HTTP_201_CREATED)
 
 
@@ -324,10 +325,11 @@ class ReImportAPI(ImportAPI):
         # after bulk create we can bulk update task stats with
         # flag_update_stats=True but they are already updated with signal in same transaction
         # so just update tasks_number_changed
-        project.update_tasks_states(
+        project.update_tasks_states_with_counters(
             maximum_annotations_changed=False,
             overlap_cohort_percentage_changed=False,
-            tasks_number_changed=True
+            tasks_number_changed=True,
+            tasks_queryset=tasks
         )
         logger.info('Tasks bulk_update finished')
 
