@@ -15,8 +15,8 @@ urlpatterns = [
     path("api/dm/columns/", api.ProjectColumnsAPI.as_view()),
     path("api/dm/project/", api.ProjectStateAPI.as_view()),
     path("api/dm/actions/", api.ProjectActionsAPI.as_view()),
-    path("api/dm/tasks/", api.TaskListAPI.as_view()),
-    path("api/dm/tasks/<int:pk>", api.TaskAPI.as_view()),
+    # path("api/dm/tasks/", api.TaskListAPI.as_view()),
+    # path("api/dm/tasks/<int:pk>", api.TaskAPI.as_view()),
 
     path("projects/<int:pk>/", views.task_page, name='project-data'),
     path("projects/<int:pk>/data/", views.task_page, name='project-data'),
