@@ -12,6 +12,7 @@ from django.db import transaction, models
 from annoying.fields import AutoOneToOneField
 from functools import lru_cache
 
+from core.redis import start_job_async_or_sync
 from tasks.models import Task, Prediction, Annotation, Q_task_finished_annotations, bulk_update_stats_project_tasks
 from core.utils.common import create_hash, get_attr_or_item, load_func
 from core.utils.exceptions import LabelStudioValidationErrorSentryIgnored
@@ -27,6 +28,7 @@ from core.label_config import (
 )
 from core.bulk_update_utils import bulk_update
 from label_studio_tools.core.label_config import parse_config
+from labels_manager.models import Label
 
 
 logger = logging.getLogger(__name__)
@@ -124,11 +126,11 @@ class Project(ProjectMixin, models.Model):
         default='<View></View>',
         help_text='Label config in XML format. See more about it in documentation',
     )
-    parsed_label_config = models.TextField(
+    parsed_label_config = models.JSONField(
         _('parsed label config'),
         blank=True,
         null=True,
-        default='',
+        default=None,
         help_text='Parsed label config in JSON format. See more about it in documentation',
     )
     expert_instruction = models.TextField(
@@ -187,7 +189,11 @@ class Project(ProjectMixin, models.Model):
         help_text='Minimum number of completed tasks after which model training is started',
     )
 
-    control_weights = JSONField(_('control weights'), null=True, default=dict, help_text='Weights for control tags')
+    control_weights = JSONField(_('control weights'), null=True, default=dict, help_text="Dict of weights for each control tag in metric calculation. Each control tag (e.g. label or choice) will "
+                                                                                         "have it's own key in control weight dict with weight for each label and overall weight." 
+                                                                                         "For example, if bounding box annotation with control tag named my_bbox should be included with 0.33 weight in agreement calculation, "
+                                                                                         "and the first label Car should be twice more important than Airplaine, then you have to need the specify: "
+                                                                                         "{'my_bbox': {'type': 'RectangleLabels', 'labels': {'Car': 1.0, 'Airplaine': 0.5}, 'overall': 0.33}")
     model_version = models.TextField(
         _('model version'), blank=True, null=True, default='', help_text='Machine learning model version'
     )
@@ -344,10 +350,9 @@ class Project(ProjectMixin, models.Model):
         membership = ProjectMember.objects.filter(user=user, project=self)
         return membership.exists() and membership.first().enabled
 
-    def update_tasks_states(
+    def _update_tasks_states(
         self, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed
     ):
-
         # if only maximum annotations parameter is tweaked
         if maximum_annotations_changed and not overlap_cohort_percentage_changed:
             tasks_with_overlap = self.tasks.filter(overlap__gt=1)
@@ -368,9 +373,31 @@ class Project(ProjectMixin, models.Model):
 
         if maximum_annotations_changed or overlap_cohort_percentage_changed or tasks_number_changed:
             bulk_update_stats_project_tasks(
-                self.tasks.filter(Q(annotations__isnull=False) & Q(annotations__ground_truth=False))
+                self.tasks.filter(Q(annotations__isnull=False))
             )
 
+    def update_tasks_states(
+        self, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed
+    ):
+        start_job_async_or_sync(self._update_tasks_states, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed)
+
+
+    def update_tasks_states_with_counters(
+        self, maximum_annotations_changed, overlap_cohort_percentage_changed,
+            tasks_number_changed, tasks_queryset
+    ):
+        start_job_async_or_sync(self._update_tasks_states_with_counters, maximum_annotations_changed,
+                                overlap_cohort_percentage_changed, tasks_number_changed, tasks_queryset)
+
+
+    def _update_tasks_states_with_counters(
+        self, maximum_annotations_changed, overlap_cohort_percentage_changed,
+            tasks_number_changed, tasks_queryset
+    ):
+        self._update_tasks_states(maximum_annotations_changed, overlap_cohort_percentage_changed,
+            tasks_number_changed)
+        self.update_tasks_counters(tasks_queryset)
+
     def _rearrange_overlap_cohort(self):
         """
         Rearrange overlap depending on annotation count in tasks
@@ -499,22 +526,31 @@ class Project(ProjectMixin, models.Model):
                 f'Created annotations are incompatible with provided labeling schema, we found:\n{diff_str}'
             )
 
+
         # validate labels consistency
-        labels_from_config = get_all_labels(config_string)
+        labels_from_config, dynamic_label_from_config = get_all_labels(config_string)
         created_labels = self.summary.created_labels
         for control_tag_from_data, labels_from_data in created_labels.items():
             # Check if labels created in annotations, and their control tag has been removed
-            if labels_from_data and control_tag_from_data not in labels_from_config:
+            if labels_from_data and ((control_tag_from_data not in labels_from_config) and (
+                    control_tag_from_data not in dynamic_label_from_config)):
                 raise LabelStudioValidationErrorSentryIgnored(
                     f'There are {sum(labels_from_data.values(), 0)} annotation(s) created with tag '
                     f'"{control_tag_from_data}", you can\'t remove it'
                 )
             labels_from_config_by_tag = set(labels_from_config[control_tag_from_data])
+            parsed_config = parse_config(config_string)
+            tag_types = [tag_info['type'] for _, tag_info in parsed_config.items()]
+            if 'Taxonomy' in tag_types:
+                custom_tags = Label.objects.filter(links__project=self).values_list('value', flat=True)
+                flat_custom_tags = set([item for sublist in custom_tags for item in sublist])
+                labels_from_config_by_tag |= flat_custom_tags
             if not set(labels_from_data).issubset(set(labels_from_config_by_tag)):
                 different_labels = list(set(labels_from_data).difference(labels_from_config_by_tag))
                 diff_str = '\n'.join(f'{l} ({labels_from_data[l]} annotations)' for l in different_labels)
-                if strict is True:
-                    raise LabelStudioValidationErrorSentryIgnored(f'These labels still exist in annotations:\n{diff_str}')
+                if (strict is True) and (control_tag_from_data not in dynamic_label_from_config):
+                    raise LabelStudioValidationErrorSentryIgnored(
+                        f'These labels still exist in annotations:\n{diff_str}')
                 else:
                     logger.warning(f'project_id={self.id} inconsistent labels in config and annotations: {diff_str}')
 
@@ -528,7 +564,7 @@ class Project(ProjectMixin, models.Model):
         return {'deleted_predictions': count}
 
     def get_updated_weights(self):
-        outputs = self.get_parsed_config()
+        outputs = self.get_parsed_config(autosave_cache=False)
         control_weights = {}
         exclude_control_types = ('Filter',)
         for control_name in outputs:
@@ -544,18 +580,20 @@ class Project(ProjectMixin, models.Model):
 
     def save(self, *args, recalc=True, **kwargs):
         exists = True if self.pk else False
+        project_with_config_just_created = not exists and self.label_config
 
-        if self.label_config and (self._label_config_has_changed() or not exists or not self.control_weights):
-            self.control_weights = self.get_updated_weights()
-        super(Project, self).save(*args, **kwargs)
-        project_with_config_just_created = not exists and self.pk and self.label_config
         if self._label_config_has_changed() or project_with_config_just_created:
             self.data_types = extract_data_types(self.label_config)
             self.parsed_label_config = parse_config(self.label_config)
 
+        if self.label_config and (self._label_config_has_changed() or not exists or not self.control_weights):
+            self.control_weights = self.get_updated_weights()
+
         if self._label_config_has_changed():
             self.__original_label_config = self.label_config
 
+        super(Project, self).save(*args, **kwargs)
+
         if not exists:
             steps = ProjectOnboardingSteps.objects.all()
             objs = [ProjectOnboarding(project=self, step=step) for step in steps]
@@ -698,13 +736,14 @@ class Project(ProjectMixin, models.Model):
     def max_tasks_file_size():
         return settings.TASKS_MAX_FILE_SIZE
 
-    def get_control_tags_from_config(self):
-        return self.get_parsed_config()
+    def get_parsed_config(self, autosave_cache=True):
+        if self.parsed_label_config is None:
+            self.parsed_label_config = parse_config(self.label_config)
 
-    def get_parsed_config(self):
-        if self.parsed_label_config:
-            return self.parsed_label_config
-        return parse_config(self.label_config)
+            # if autosave_cache:
+            #    Project.objects.filter(id=self.id).update(parsed_label_config=self.parsed_label_config)
+
+        return self.parsed_label_config
 
     def get_counters(self):
         """Method to get extra counters data from Manager method with_counts()
@@ -741,6 +780,42 @@ class Project(ProjectMixin, models.Model):
         self._storage_objects = storage_objects
         return storage_objects
 
+    def update_tasks_counters(self, queryset, from_scratch=True):
+        objs = []
+
+        total_annotations = Count("annotations", distinct=True, filter=Q(annotations__was_cancelled=False))
+        cancelled_annotations = Count("annotations", distinct=True, filter=Q(annotations__was_cancelled=True))
+        total_predictions = Count("predictions", distinct=True)
+        if isinstance(queryset, list):
+            queryset = Task.objects.filter(id__in=[task.id for task in queryset])
+
+        if not from_scratch:
+            queryset = queryset.exclude(
+                Q(total_annotations__gt=0) |
+                Q(cancelled_annotations__gt=0) |
+                Q(total_predictions__gt=0)
+            )
+
+        # filter our tasks with 0 annotations and 0 predictions and update them with 0
+        queryset.filter(annotations__isnull=True, predictions__isnull=True).\
+            update(total_annotations=0, cancelled_annotations=0, total_predictions=0)
+
+        # filter our tasks with 0 annotations and 0 predictions
+        queryset = queryset.filter(Q(annotations__isnull=False) | Q(predictions__isnull=False))
+        queryset = queryset.annotate(new_total_annotations=total_annotations,
+                                     new_cancelled_annotations=cancelled_annotations,
+                                     new_total_predictions=total_predictions)
+
+        for task in queryset.only('id', 'total_annotations', 'cancelled_annotations', 'total_predictions'):
+            task.total_annotations = task.new_total_annotations
+            task.cancelled_annotations = task.new_cancelled_annotations
+            task.total_predictions = task.new_total_predictions
+            objs.append(task)
+
+        with transaction.atomic():
+            bulk_update(objs, update_fields=['total_annotations', 'cancelled_annotations', 'total_predictions'], batch_size=settings.BATCH_SIZE)
+        return len(objs)
+
     def __str__(self):
         return f'{self.title} (id={self.id})' or _("Business number %d") % self.pk
 
@@ -862,7 +937,7 @@ class ProjectSummary(models.Model):
             self.common_data_columns = list(sorted(set(self.common_data_columns) & common_data_columns))
         logger.debug(f'summary.all_data_columns = {self.all_data_columns}')
         logger.debug(f'summary.common_data_columns = {self.common_data_columns}')
-        self.save()
+        self.save(update_fields=['all_data_columns', 'common_data_columns'])
 
     def remove_data_columns(self, tasks):
         all_data_columns = dict(self.all_data_columns)
@@ -886,7 +961,7 @@ class ProjectSummary(models.Model):
             self.common_data_columns = common_data_columns
         logger.debug(f'summary.all_data_columns = {self.all_data_columns}')
         logger.debug(f'summary.common_data_columns = {self.common_data_columns}')
-        self.save()
+        self.save(update_fields=['all_data_columns', 'common_data_columns', ])
 
     def _get_annotation_key(self, result):
         result_type = result.get('type', None)
@@ -946,7 +1021,7 @@ class ProjectSummary(models.Model):
         logger.debug(f'summary.created_labels = {labels}')
         self.created_annotations = created_annotations
         self.created_labels = labels
-        self.save()
+        self.save(update_fields=['created_annotations', 'created_labels'])
 
     def remove_created_annotations_and_labels(self, annotations):
         created_annotations = dict(self.created_annotations)
@@ -980,4 +1055,4 @@ class ProjectSummary(models.Model):
         logger.debug(f'summary.created_labels = {labels}')
         self.created_annotations = created_annotations
         self.created_labels = labels
-        self.save()
\ No newline at end of file
+        self.save(update_fields=['created_annotations', 'created_labels'])
