@@ -1,11 +1,11 @@
 """This file and its contents are licensed under the Apache License 2.0. Please see the included NOTICE for copyright information and LICENSE for a copy of the license.
 """
-from core.label_config import generate_sample_task_without_check
-from drf_dynamic_fields import DynamicFieldsMixin
 from rest_framework import serializers
+from rest_flex_fields import FlexFieldsModelSerializer
 from rest_framework.serializers import SerializerMethodField
 from users.serializers import UserSimpleSerializer
 
+
 from projects.models import Project, ProjectOnboarding, ProjectSummary
 
 
@@ -16,13 +16,13 @@ class CreatedByFromContext:
         return serializer_field.context.get('created_by')
 
 
-class ProjectSerializer(DynamicFieldsMixin, serializers.ModelSerializer):
+class ProjectSerializer(FlexFieldsModelSerializer):
     """ Serializer get numbers from project queryset annotation,
         make sure, that you use correct one(Project.objects.with_counts())
     """
 
     task_number = serializers.IntegerField(default=None, read_only=True,
-                                        help_text='Total task number in project')
+                                           help_text='Total task number in project')
     total_annotations_number = serializers.IntegerField(default=None, read_only=True,
                                                     help_text='Total annotations number in project including '
                                                               'skipped_annotations_number and ground_truth_number.')
@@ -40,7 +40,8 @@ class ProjectSerializer(DynamicFieldsMixin, serializers.ModelSerializer):
     skipped_annotations_number = serializers.IntegerField(default=None, read_only=True,
                                                       help_text='Skipped by collaborators annotation number in project')
     num_tasks_with_annotations = serializers.IntegerField(default=None, read_only=True, help_text='Tasks with annotations count')
-    created_by = UserSimpleSerializer(default=CreatedByFromContext())
+
+    created_by = UserSimpleSerializer(default=CreatedByFromContext(), help_text='Project owner')
 
     parsed_label_config = SerializerMethodField(default=None, read_only=True,
                                                 help_text='JSON-formatted labeling configuration')
@@ -51,7 +52,7 @@ class ProjectSerializer(DynamicFieldsMixin, serializers.ModelSerializer):
 
     @staticmethod
     def get_config_has_control_tags(project):
-        return len(project.get_control_tags_from_config()) > 0
+        return len(project.get_parsed_config()) > 0
 
     @staticmethod
     def get_parsed_label_config(project):
