@@ -19,10 +19,21 @@ _DATA_TYPES = {
     'HyperText': [str],
     'Image': [str, list],
     'Paragraphs': [list, str],
-    'Table': [dict],
+    'Table': [dict, str],
     'TimeSeries': [dict, list, str],
     'TimeSeriesChannel': [dict, list, str],
-    'List': [list]
+    'List': [list],
+    'Choices': [str, list],
+    'PolygonLabels': [str, list],
+    'Labels': [str, list],
+    'BrushLabels': [str, list],
+    'EllipseLabels': [str, list],
+    'HyperTextLabels': [str, list],
+    'KeyPointLabels': [str, list],
+    'ParagraphLabels': [str, list],
+    'RectangleLabels': [str, list],
+    'TimeSeriesLabels': [str, list],
+    'Taxonomy': [str, list],
 }
 logger = logging.getLogger(__name__)
 
