@@ -274,5 +274,18 @@ def os_independent_path(_, path, add_tempdir=False):
         {
             'os_independent_path': str(os_independent_path),
             'os_independent_path_parent': str(os_independent_path_parent),
+            'os_independent_path_tmpdir': str(Path(tempfile.gettempdir())),
         }
     )
+
+def verify_docs(response):
+    for _, path in response.json()['paths'].items():
+        print(path)
+        for _, method in path.items():
+            print(method)
+            if isinstance(method, dict):
+                assert 'api' not in method['tags'], f'Need docs for API method {method}'
+
+
+def empty_list(response):
+    assert len(response.json()) == 0, f'Response should be empty, but is {response.json()}'
