@@ -9,6 +9,9 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 from projects.models import Project
 from tasks.models import Annotation, Task
+from labels_manager.models import LabelLink
+# from labels_manager.serializers import LabelLinkSerializer, LabelSerializer
+
 
 from .serializers_for_hooks import (
     OnlyIDWebhookSerializer,
@@ -39,30 +42,33 @@ class Webhook(models.Model):
     url = models.URLField(_('URL of webhook'), max_length=2048, help_text=_('URL of webhook'))
 
     send_payload = models.BooleanField(
-        _("does webhook send the payload"), default=True, help_text=('If value is False send only action')
+        _("does webhook send the payload"), default=True, help_text=('If value is False send only action'),
+        db_index=True
     )
 
     send_for_all_actions = models.BooleanField(
         _("Use webhook for all actions"),
         default=True,
-        help_text=('If value is False - used only for actions from WebhookAction'),
+        help_text='If value is False - used only for actions from WebhookAction',
+        db_index=True
     )
 
     headers = models.JSONField(
         _("request extra headers of webhook"),
         validators=[JSONSchemaValidator(HEADERS_SCHEMA)],
         default=dict,
-        help_text=('Key Value Json of headers'),
+        help_text='Key Value Json of headers',
     )
 
     is_active = models.BooleanField(
         _("is webhook active"),
         default=True,
         help_text=('If value is False the webhook is disabled'),
+        db_index=True
     )
 
-    created_at = models.DateTimeField(_('created at'), auto_now_add=True, help_text=_('Creation time'))
-    updated_at = models.DateTimeField(_('updated at'), auto_now=True, help_text=_('Last update time'))
+    created_at = models.DateTimeField(_('created at'), auto_now_add=True, help_text=_('Creation time'), db_index=True)
+    updated_at = models.DateTimeField(_('updated at'), auto_now=True, help_text=_('Last update time'), db_index=True)
 
     def get_actions(self):
         return WebhookAction.objects.filter(webhook=self).values_list('action', flat=True)
@@ -100,9 +106,15 @@ class WebhookAction(models.Model):
     TASKS_DELETED = 'TASKS_DELETED'
 
     ANNOTATION_CREATED = 'ANNOTATION_CREATED'
+    ANNOTATIONS_CREATED = 'ANNOTATIONS_CREATED'
     ANNOTATION_UPDATED = 'ANNOTATION_UPDATED'
     ANNOTATIONS_DELETED = 'ANNOTATIONS_DELETED'
 
+    LABEL_LINK_CREATED = 'LABEL_LINK_CREATED'
+    LABEL_LINK_UPDATED = 'LABEL_LINK_UPDATED'
+    LABEL_LINK_DELETED = 'LABEL_LINK_DELETED'
+
+
     ACTIONS = {
         PROJECT_CREATED: {
             'name': _('Project created'),
@@ -165,6 +177,22 @@ class WebhookAction(models.Model):
                 },
             },
         },
+        ANNOTATIONS_CREATED: {
+            'name': _('Annotations created'),
+            'description': _(''),
+            'key': 'annotation',
+            'many': True,
+            'model': Annotation,
+            'serializer': load_func(settings.WEBHOOK_SERIALIZERS['annotation']),
+            'project-field': 'task__project',
+            'nested-fields': {
+                'task': {
+                    'serializer': load_func(settings.WEBHOOK_SERIALIZERS['task']),
+                    'many': True,
+                    'field': 'task',
+                },
+            },
+        },
         ANNOTATION_UPDATED: {
             'name': _('Annotation updated'),
             'description': _(''),
@@ -190,6 +218,41 @@ class WebhookAction(models.Model):
             'serializer': OnlyIDWebhookSerializer,
             'project-field': 'task__project',
         },
+        LABEL_LINK_CREATED: {
+            'name': _('Label link created'),
+            'description': _(''),
+            'key': 'label_link',
+            'many': True,
+            'model': LabelLink,
+            'serializer': load_func(settings.WEBHOOK_SERIALIZERS['label_link']),
+            'project-field': 'project',
+        },
+        LABEL_LINK_UPDATED: {
+            'name': _('Label link updated'),
+            'description': _(''),
+            'key': 'label_link',
+            'many': False,
+            'model': LabelLink,
+            'serializer': load_func(settings.WEBHOOK_SERIALIZERS['label_link']),
+            'project-field': 'project',
+            'nested-fields': {
+                'label': {
+                    'many': False,
+                    'field': 'label',
+                    'serializer': load_func(settings.WEBHOOK_SERIALIZERS['label']),
+                },
+            }
+        },
+        LABEL_LINK_DELETED: {
+            'name': _('Label link deleted'),
+            'description': _(''),
+            'key': 'label_link',
+            'many': False,
+            'model': LabelLink,
+            'serializer': OnlyIDWebhookSerializer,
+            'project-field': 'project',
+        },
+
     }
 
     webhook = models.ForeignKey(Webhook, on_delete=models.CASCADE, related_name='actions')
